ethextended
===========
Library with extra tools for ethereum, provided by Etherscan, Eth Gas Station, etc.

.. image:: https://travis-ci.org/AlexSSD7/ethextended.svg?branch=master
    :target: https://travis-ci.org/AlexSSD7/ethextended

.. image:: https://readthedocs.org/projects/ethextended/badge/?version=latest
	:target: https://ethextended.readthedocs.io/en/latest/?badge=latest


`💎 Read The Docs 💎 <https://ethextended.readthedocs.io/>`_

Installation
------------
Install using **pip**:

.. code-block:: shell

	$ pip3 install ethextended

Or build from **source**:

.. code-block:: shell

	$ python3 setup.py install
